@@ -2,8 +2,10 @@ import cv2
 import numpy as np
 import copy
 
+
 class image_dehazer():
-    def __init__(self, airlightEstimation_windowSze=15, boundaryConstraint_windowSze=3, C0=20, C1=300, regularize_lambda=0.1, sigma=0.5, delta=0.85, showHazeTrasmissionMap=True):
+    def __init__(self, airlightEstimation_windowSze=15, boundaryConstraint_windowSze=3, C0=20, C1=300,
+                 regularize_lambda=0.1, sigma=0.5, delta=0.85, showHazeTransmissionMap=True):
         self.airlightEstimation_windowSze = airlightEstimation_windowSze
         self.boundaryConstraint_windowSze = boundaryConstraint_windowSze
         self.C0 = C0
@@ -11,7 +13,7 @@ class image_dehazer():
         self.regularize_lambda = regularize_lambda
         self.sigma = sigma
         self.delta = delta
-        self.showHazeTrasmissionMap=showHazeTrasmissionMap
+        self.showHazeTransmissionMap = showHazeTransmissionMap
         self._A = []
         self._transmission = []
         self._WFun = []
@@ -75,10 +77,10 @@ class image_dehazer():
             Blue = HazeImageDouble[:, :, 0]
             d_b = self.__circularConvFilt(Blue, Filter)
 
-            return(np.exp(-((d_r ** 2) + (d_g ** 2) + (d_b ** 2)) / (2 * self.sigma * self.sigma)))
+            return (np.exp(-((d_r ** 2) + (d_g ** 2) + (d_b ** 2)) / (2 * self.sigma * self.sigma)))
         else:
             d = self.__circularConvFilt(HazeImageDouble, Filter)
-            return(np.exp(-((d ** 2) + (d ** 2) + (d ** 2)) / (2 * self.sigma * self.sigma)))
+            return (np.exp(-((d ** 2) + (d ** 2) + (d ** 2)) / (2 * self.sigma * self.sigma)))
 
     def __circularConvFilt(self, Img, Filter):
         FilterHeight, FilterWidth = Filter.shape
@@ -91,7 +93,7 @@ class image_dehazer():
                                        borderType=cv2.BORDER_WRAP)
         FilteredImg = cv2.filter2D(PaddedImg, -1, Filter)
         Result = FilteredImg[filterHalsSize:rows + filterHalsSize, filterHalsSize:cols + filterHalsSize]
-        return(Result)
+        return (Result)
 
     def __CalTransmission(self, HazeImg):
         rows, cols = self._Transmission.shape
@@ -137,8 +139,8 @@ class image_dehazer():
 
             self._Transmission = np.abs(np.fft.ifft2((gamma * tF + DU) / (gamma + DS)))
             beta = beta * beta_rate
-        
-        if(self.showHazeTrasmissionMap):
+
+        if (self.showHazeTransmissionMap):
             cv2.imshow("Haze Transmission Map", self._Transmission)
             cv2.waitKey(1)
 
@@ -286,11 +288,15 @@ class image_dehazer():
         self.__BoundCon(HazeImg)
         self.__CalTransmission(HazeImg)
         haze_corrected_img = self.__removeHaze(HazeImg)
-        return (haze_corrected_img)
+        HazeTransmissionMap = self._Transmission
+        return (haze_corrected_img, HazeTransmissionMap)
 
-def remove_haze(HazeImg, airlightEstimation_windowSze=15, boundaryConstraint_windowSze=3, C0=20, C1=300, regularize_lambda=0.1, sigma=0.5, delta=0.85, showHazeTrasmissionMap=True):
+
+def remove_haze(HazeImg, airlightEstimation_windowSze=15, boundaryConstraint_windowSze=3, C0=20, C1=300,
+                regularize_lambda=0.1, sigma=0.5, delta=0.85, showHazeTransmissionMap=True):
     Dehazer = image_dehazer(airlightEstimation_windowSze=airlightEstimation_windowSze,
                             boundaryConstraint_windowSze=boundaryConstraint_windowSze, C0=C0, C1=C1,
-                            regularize_lambda=regularize_lambda, sigma=sigma, delta=delta, showHazeTrasmissionMap=showHazeTrasmissionMap)
-    HazeCorrectedImg = Dehazer.remove_haze(HazeImg)
-    return(HazeCorrectedImg)
\ No newline at end of file
+                            regularize_lambda=regularize_lambda, sigma=sigma, delta=delta,
+                            showHazeTransmissionMap=showHazeTransmissionMap)
+    HazeCorrectedImg, HazeTransmissionMap = Dehazer.remove_haze(HazeImg)
+    return (HazeCorrectedImg, HazeTransmissionMap)
\ No newline at end of file
